[Libreoffice-commits] .: 8 commits - chart2/inc chart2/source chart2/workbench scaddins/source sc/inc sc/source sc/util sc/workben
Norbert Thiebaud
nthiebaud at kemper.freedesktop.org
Mon Oct 25 19:26:41 PDT 2010
chart2/inc/pch/precompiled_chart2.hxx | 2
chart2/source/controller/accessibility/AccStatisticsObject.cxx | 2
chart2/source/controller/accessibility/AccessibleBase.cxx | 2
chart2/source/controller/accessibility/AccessibleChartElement.cxx | 4
chart2/source/controller/accessibility/AccessibleChartView.cxx | 2
chart2/source/controller/accessibility/AccessibleTextHelper.cxx | 8
chart2/source/controller/dialogs/dlg_CreationWizard_UNO.cxx | 18
chart2/source/controller/main/ChartController.cxx | 46 -
chart2/source/controller/main/ChartController_EditData.cxx | 4
chart2/source/controller/main/ChartController_Insert.cxx | 20
chart2/source/controller/main/ChartController_Position.cxx | 4
chart2/source/controller/main/ChartController_Properties.cxx | 6
chart2/source/controller/main/ChartController_TextEdit.cxx | 4
chart2/source/controller/main/ChartController_Tools.cxx | 8
chart2/source/controller/main/ChartController_Window.cxx | 20
chart2/source/controller/main/ChartRenderer.cxx | 6
chart2/source/controller/main/DrawCommandDispatch.cxx | 6
chart2/source/controller/main/ElementSelector.cxx | 4
chart2/source/controller/main/SelectionHelper.cxx | 24
chart2/source/controller/main/ShapeController.cxx | 22
chart2/source/controller/main/ShapeToolbarController.cxx | 12
chart2/source/controller/main/UndoCommandDispatch.cxx | 4
chart2/source/view/main/ChartView.cxx | 20
chart2/workbench/addin/makefile.mk | 3
sc/inc/document.hxx | 10
sc/inc/pch/precompiled_sc.hxx | 3
sc/inc/refreshtimer.hxx | 8
sc/inc/unoguard.hxx | 42
sc/source/core/data/documen2.cxx | 4
sc/source/core/data/documen3.cxx | 5
sc/source/core/data/documen9.cxx | 4
sc/source/core/data/document.cxx | 2
sc/source/core/data/dptabsrc.cxx | 10
sc/source/core/inc/poolhelp.hxx | 4
sc/source/core/tool/addincol.cxx | 1
sc/source/core/tool/addinlis.cxx | 4
sc/source/core/tool/refreshtimer.cxx | 4
sc/source/filter/inc/filt_pch.hxx | 6
sc/source/filter/lotus/lotimpop.cxx | 4
sc/source/filter/xml/XMLDDELinksContext.cxx | 2
sc/source/filter/xml/XMLTableHeaderFooterContext.cxx | 1
sc/source/filter/xml/XMLTableShapeImportHelper.cxx | 2
sc/source/filter/xml/XMLTrackedChangesContext.cxx | 2
sc/source/filter/xml/sheetdata.cxx | 2
sc/source/filter/xml/xmlcelli.cxx | 2
sc/source/filter/xml/xmldpimp.cxx | 2
sc/source/filter/xml/xmlexprt.cxx | 17
sc/source/filter/xml/xmlimprt.cxx | 21
sc/source/filter/xml/xmlimprt.hxx | 4
sc/source/filter/xml/xmlsceni.cxx | 2
sc/source/filter/xml/xmlstyli.cxx | 3
sc/source/filter/xml/xmlwrap.cxx | 3
sc/source/ui/Accessibility/AccessibleCell.cxx | 10
sc/source/ui/Accessibility/AccessibleCellBase.cxx | 16
sc/source/ui/Accessibility/AccessibleContextBase.cxx | 32
sc/source/ui/Accessibility/AccessibleCsvControl.cxx | 114 +-
sc/source/ui/Accessibility/AccessibleDataPilotControl.cxx | 40
sc/source/ui/Accessibility/AccessibleDocument.cxx | 44 -
sc/source/ui/Accessibility/AccessibleDocumentPagePreview.cxx | 28
sc/source/ui/Accessibility/AccessibleEditObject.cxx | 14
sc/source/ui/Accessibility/AccessibleFilterMenu.cxx | 1
sc/source/ui/Accessibility/AccessiblePageHeader.cxx | 14
sc/source/ui/Accessibility/AccessiblePageHeaderArea.cxx | 14
sc/source/ui/Accessibility/AccessiblePreviewCell.cxx | 16
sc/source/ui/Accessibility/AccessiblePreviewHeaderCell.cxx | 20
sc/source/ui/Accessibility/AccessiblePreviewTable.cxx | 44 -
sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx | 42
sc/source/ui/Accessibility/AccessibleTableBase.cxx | 26
sc/source/ui/Accessibility/AccessibleText.cxx | 6
sc/source/ui/app/drwtrans.cxx | 6
sc/source/ui/app/transobj.cxx | 5
sc/source/ui/docshell/docsh2.cxx | 6
sc/source/ui/inc/AccessibleContextBase.hxx | 2
sc/source/ui/unoobj/addruno.cxx | 4
sc/source/ui/unoobj/afmtuno.cxx | 52 -
sc/source/ui/unoobj/appluno.cxx | 35
sc/source/ui/unoobj/cellsuno.cxx | 425 ++++------
sc/source/ui/unoobj/chart2uno.cxx | 62 -
sc/source/ui/unoobj/chartuno.cxx | 39
sc/source/ui/unoobj/confuno.cxx | 8
sc/source/ui/unoobj/cursuno.cxx | 36
sc/source/ui/unoobj/dapiuno.cxx | 240 ++---
sc/source/ui/unoobj/datauno.cxx | 118 +-
sc/source/ui/unoobj/defltuno.cxx | 16
sc/source/ui/unoobj/dispuno.cxx | 22
sc/source/ui/unoobj/docuno.cxx | 195 ++--
sc/source/ui/unoobj/editsrc.cxx | 4
sc/source/ui/unoobj/eventuno.cxx | 14
sc/source/ui/unoobj/fielduno.cxx | 54 -
sc/source/ui/unoobj/filtuno.cxx | 4
sc/source/ui/unoobj/fmtuno.cxx | 70 -
sc/source/ui/unoobj/forbiuno.cxx | 6
sc/source/ui/unoobj/funcuno.cxx | 11
sc/source/ui/unoobj/linkuno.cxx | 180 ++--
sc/source/ui/unoobj/makefile.mk | 1
sc/source/ui/unoobj/miscuno.cxx | 6
sc/source/ui/unoobj/nameuno.cxx | 86 +-
sc/source/ui/unoobj/notesuno.cxx | 114 +-
sc/source/ui/unoobj/optuno.cxx | 5
sc/source/ui/unoobj/scdetect.cxx | 4
sc/source/ui/unoobj/servuno.cxx | 9
sc/source/ui/unoobj/shapeuno.cxx | 58 -
sc/source/ui/unoobj/srchuno.cxx | 16
sc/source/ui/unoobj/styleuno.cxx | 72 -
sc/source/ui/unoobj/targuno.cxx | 3
sc/source/ui/unoobj/textuno.cxx | 64 -
sc/source/ui/unoobj/tokenuno.cxx | 12
sc/source/ui/unoobj/unodoc.cxx | 4
sc/source/ui/unoobj/unoguard.cxx | 49 -
sc/source/ui/unoobj/viewuno.cxx | 94 +-
sc/util/makefile.mk | 3
sc/workben/addin.cxx | 2
sc/workben/makefile.mk | 2
scaddins/source/datefunc/msdev.mk | 1
114 files changed, 1515 insertions(+), 1610 deletions(-)
New commits:
commit 4df20220a7ae3119141f572a12a2b887d7a12c50
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Thu Oct 21 16:26:15 2010 -0500
Finally, gut the vos module out of the build
diff --git a/chart2/workbench/addin/makefile.mk b/chart2/workbench/addin/makefile.mk
index 2a7ebd1..380a0ce 100644
--- a/chart2/workbench/addin/makefile.mk
+++ b/chart2/workbench/addin/makefile.mk
@@ -73,8 +73,7 @@ SHL1OBJS=$(SLOFILES)
SHL1STDLIBS= \
$(CPPUHELPERLIB) \
$(CPPULIB) \
- $(VOSLIB) \
- $(SALLIB)
+ $(SALLIB)
SHL1DEPN=makefile.mk
SHL1DEF=$(MISC)$/$(SHL1TARGET).def
diff --git a/sc/util/makefile.mk b/sc/util/makefile.mk
index c6c2abc..5b9c165 100644
--- a/sc/util/makefile.mk
+++ b/sc/util/makefile.mk
@@ -86,7 +86,6 @@ SHL1STDLIBS= \
$(COMPHELPERLIB) \
$(UCBHELPERLIB) \
$(TKLIB) \
- $(VOSLIB) \
$(SALLIB) \
$(SALHELPERLIB) \
$(TOOLSLIB) \
@@ -193,7 +192,6 @@ SHL6STDLIBS= \
$(CPPUHELPERLIB) \
$(COMPHELPERLIB) \
$(TKLIB) \
- $(VOSLIB) \
$(SALLIB) \
$(TOOLSLIB) \
$(UNOTOOLSLIB) \
diff --git a/sc/workben/makefile.mk b/sc/workben/makefile.mk
index 08d09a6..ba5ebbb 100644
--- a/sc/workben/makefile.mk
+++ b/sc/workben/makefile.mk
@@ -68,7 +68,7 @@ EXCEPTIONSFILES= \
SHL1TARGET= $(TARGET)$(DLLPOSTFIX)
-SHL1STDLIBS=$(VCLLIB) $(TOOLSLIB) $(SVLLIB) $(TKLIB) $(SALLIB) $(VOSLIB) $(CPPULIB) $(CPPUHELPERLIB)
+SHL1STDLIBS=$(VCLLIB) $(TOOLSLIB) $(SVLLIB) $(TKLIB) $(SALLIB) $(CPPULIB) $(CPPUHELPERLIB)
SHL1DEPN= $(L)$/itools.lib $(SVLIBDEPEND)
SHL1DEF= $(MISC)$/$(SHL1TARGET).def
diff --git a/scaddins/source/datefunc/msdev.mk b/scaddins/source/datefunc/msdev.mk
index d50fb23..3f99d2e 100644
--- a/scaddins/source/datefunc/msdev.mk
+++ b/scaddins/source/datefunc/msdev.mk
@@ -40,7 +40,6 @@ PROJECT=datefunc
TARGET=$(BINOUT)\datefunc.dll
CPPFLAGS = \
- -I$(RUNTIME)\vos\inc \
-I$(RUNTIME)\sal\inc \
-I$(RUNTIME)\cppu\inc \
-I$(RUNTIME)\cppuhelper\inc \
commit 1c3d4c35f42ab9ad4ed726623cd24d24891a0fe5
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Thu Oct 21 15:38:36 2010 -0500
remvove vos/macros.h usage
diff --git a/sc/inc/pch/precompiled_sc.hxx b/sc/inc/pch/precompiled_sc.hxx
index 0b69bf5..6ec1eb3 100644
--- a/sc/inc/pch/precompiled_sc.hxx
+++ b/sc/inc/pch/precompiled_sc.hxx
@@ -236,9 +236,6 @@
#include <vcl/vclevent.hxx>
#include <vcl/window.hxx>
#include <vcl/wintypes.hxx>
-#include <vos/macros.hxx>
-#include <vos/object.hxx>
-#include <vos/types.hxx>
#include <wchar.h>
#endif
diff --git a/sc/source/core/tool/addincol.cxx b/sc/source/core/tool/addincol.cxx
index 3ff5b7d..e44946b 100644
--- a/sc/source/core/tool/addincol.cxx
+++ b/sc/source/core/tool/addincol.cxx
@@ -35,7 +35,6 @@
#include <tools/debug.hxx>
#include <i18npool/mslangid.hxx>
#include <vcl/svapp.hxx>
-#include <vos/xception.hxx>
#include <sfx2/objsh.hxx>
#include <unotools/charclass.hxx>
diff --git a/sc/source/filter/inc/filt_pch.hxx b/sc/source/filter/inc/filt_pch.hxx
index 1fc2fdb..9ce3ce9 100644
--- a/sc/source/filter/inc/filt_pch.hxx
+++ b/sc/source/filter/inc/filt_pch.hxx
@@ -155,9 +155,6 @@
#include <tools/shl.hxx>
#include <tools/pstm.hxx>
#include <editeng/fhgtitem.hxx>
-#include <vos/types.hxx>
-#include <vos/object.hxx>
-#include <vos/macros.hxx>
#include <tools/unqid.hxx>
#include <com/sun/star/uno/Sequence.h>
#include <uno/sequence2.h>
@@ -221,7 +218,6 @@
#include <com/sun/star/container/NoSuchElementException.hpp>
#include <vcl/svapp.hxx>
#include <osl/thread.hxx>
-#include <vos/runnable.hxx>
#include <salhelper/simplereferenceobject.hxx>
#include <vcl/apptypes.hxx>
#include <editeng/editdata.hxx>
diff --git a/sc/source/filter/xml/xmlwrap.cxx b/sc/source/filter/xml/xmlwrap.cxx
index 880a147..de75372 100644
--- a/sc/source/filter/xml/xmlwrap.cxx
+++ b/sc/source/filter/xml/xmlwrap.cxx
@@ -37,7 +37,6 @@
#include <sfx2/docfile.hxx>
#include <sfx2/objsh.hxx>
#include <tools/debug.hxx>
-#include <vos/xception.hxx>
#include <comphelper/processfactory.hxx>
#include <unotools/streamwrap.hxx>
#include <svx/xmlgrhlp.hxx>
commit 336b645aeed33d2bad4850af2d4b811b29972701
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Sat Oct 16 03:15:13 2010 -0500
merge vosremoval-mutex.diff
In practice the changeset is 'inspired' by vosremoval-mutex.diff
but was essentially redone manually
diff --git a/chart2/inc/pch/precompiled_chart2.hxx b/chart2/inc/pch/precompiled_chart2.hxx
index 06888d3..8f44927 100644
--- a/chart2/inc/pch/precompiled_chart2.hxx
+++ b/chart2/inc/pch/precompiled_chart2.hxx
@@ -270,6 +270,6 @@
#include "vcl/fldunit.hxx"
-#include "vos/mutex.hxx"
+#include "osl/mutex.hxx"
//---MARKER---
#endif
diff --git a/chart2/source/controller/accessibility/AccessibleTextHelper.cxx b/chart2/source/controller/accessibility/AccessibleTextHelper.cxx
index afd3d8a..8f15795 100644
--- a/chart2/source/controller/accessibility/AccessibleTextHelper.cxx
+++ b/chart2/source/controller/accessibility/AccessibleTextHelper.cxx
@@ -33,7 +33,7 @@
#include "DrawViewWrapper.hxx"
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <svx/AccessibleTextHelper.hxx>
#include <svx/unoshtxt.hxx>
diff --git a/chart2/source/controller/dialogs/dlg_CreationWizard_UNO.cxx b/chart2/source/controller/dialogs/dlg_CreationWizard_UNO.cxx
index e6003ca..9961089 100644
--- a/chart2/source/controller/dialogs/dlg_CreationWizard_UNO.cxx
+++ b/chart2/source/controller/dialogs/dlg_CreationWizard_UNO.cxx
@@ -36,7 +36,7 @@
#include "ContainerHelper.hxx"
#include "TimerTriggeredControllerLock.hxx"
#include <osl/mutex.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
// header for class Application
#include <vcl/svapp.hxx>
#include <toolkit/awt/vclxwindow.hxx>
diff --git a/chart2/source/controller/main/ChartController.cxx b/chart2/source/controller/main/ChartController.cxx
index 3b8c4b9..e4983d0 100644
--- a/chart2/source/controller/main/ChartController.cxx
+++ b/chart2/source/controller/main/ChartController.cxx
@@ -77,7 +77,7 @@
#include <toolkit/awt/vclxwindow.hxx>
#include <toolkit/helper/vclunohelper.hxx>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
//-------
#include <com/sun/star/frame/XLayoutManager.hpp>
#include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
diff --git a/chart2/source/controller/main/ChartController_EditData.cxx b/chart2/source/controller/main/ChartController_EditData.cxx
index 9b41411..21a182c 100644
--- a/chart2/source/controller/main/ChartController_EditData.cxx
+++ b/chart2/source/controller/main/ChartController_EditData.cxx
@@ -42,7 +42,7 @@
// for RET_OK
#include <vcl/msgbox.hxx>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <com/sun/star/chart2/XChartDocument.hpp>
using namespace ::com::sun::star;
diff --git a/chart2/source/controller/main/ChartController_Insert.cxx b/chart2/source/controller/main/ChartController_Insert.cxx
index cb2bd3f..9d678bc 100644
--- a/chart2/source/controller/main/ChartController_Insert.cxx
+++ b/chart2/source/controller/main/ChartController_Insert.cxx
@@ -76,7 +76,7 @@
// header for class Application
#include <vcl/svapp.hxx>
// header for class ::vos::OGuard
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
using namespace ::com::sun::star;
diff --git a/chart2/source/controller/main/ChartController_Position.cxx b/chart2/source/controller/main/ChartController_Position.cxx
index 522e6ab..abe7905 100644
--- a/chart2/source/controller/main/ChartController_Position.cxx
+++ b/chart2/source/controller/main/ChartController_Position.cxx
@@ -50,7 +50,7 @@
#include <svx/svxdlg.hxx>
#include <svx/dialogs.hrc>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
//.............................................................................
namespace chart
diff --git a/chart2/source/controller/main/ChartController_Properties.cxx b/chart2/source/controller/main/ChartController_Properties.cxx
index ebe0052..dff8e65 100644
--- a/chart2/source/controller/main/ChartController_Properties.cxx
+++ b/chart2/source/controller/main/ChartController_Properties.cxx
@@ -70,7 +70,7 @@
#include <vcl/msgbox.hxx>
// for SolarMutex
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <svx/ActionDescriptionProvider.hxx>
//.............................................................................
diff --git a/chart2/source/controller/main/ChartController_TextEdit.cxx b/chart2/source/controller/main/ChartController_TextEdit.cxx
index 70e7e8e..083eacf 100644
--- a/chart2/source/controller/main/ChartController_TextEdit.cxx
+++ b/chart2/source/controller/main/ChartController_TextEdit.cxx
@@ -48,7 +48,7 @@
#include <svx/svxdlg.hxx>
#include <svx/dialogs.hrc>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <com/sun/star/beans/XPropertySet.hpp>
#include <svl/stritem.hxx>
#include <editeng/fontitem.hxx>
diff --git a/chart2/source/controller/main/ChartController_Tools.cxx b/chart2/source/controller/main/ChartController_Tools.cxx
index 7e321b7..a6353c9 100644
--- a/chart2/source/controller/main/ChartController_Tools.cxx
+++ b/chart2/source/controller/main/ChartController_Tools.cxx
@@ -78,7 +78,7 @@
#include <unotools/streamwrap.hxx>
// for SolarMutex
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <svx/dialmgr.hxx>
#include <svx/dialogs.hrc>
// for OutlinerView
diff --git a/chart2/source/controller/main/ChartController_Window.cxx b/chart2/source/controller/main/ChartController_Window.cxx
index 14f9b57..b0882f8 100644
--- a/chart2/source/controller/main/ChartController_Window.cxx
+++ b/chart2/source/controller/main/ChartController_Window.cxx
@@ -81,7 +81,7 @@
// header for class SdrDragMethod
#include <svx/svddrgmt.hxx>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
// for InfoBox
#include <vcl/msgbox.hxx>
diff --git a/chart2/source/controller/main/ChartRenderer.cxx b/chart2/source/controller/main/ChartRenderer.cxx
index e953509..11f6417 100644
--- a/chart2/source/controller/main/ChartRenderer.cxx
+++ b/chart2/source/controller/main/ChartRenderer.cxx
@@ -38,7 +38,7 @@
#include "macros.hxx"
#include "ChartModelHelper.hxx"
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <com/sun/star/util/XUpdatable.hpp>
diff --git a/chart2/source/controller/main/DrawCommandDispatch.cxx b/chart2/source/controller/main/DrawCommandDispatch.cxx
index 10cb25e..320b353 100644
--- a/chart2/source/controller/main/DrawCommandDispatch.cxx
+++ b/chart2/source/controller/main/DrawCommandDispatch.cxx
@@ -36,7 +36,7 @@
#include "chartview/DrawModelWrapper.hxx"
#include "macros.hxx"
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>
#include <svl/itempool.hxx>
#include <editeng/adjitem.hxx>
diff --git a/chart2/source/controller/main/ElementSelector.cxx b/chart2/source/controller/main/ElementSelector.cxx
index cda03ef..43a9e65 100644
--- a/chart2/source/controller/main/ElementSelector.cxx
+++ b/chart2/source/controller/main/ElementSelector.cxx
@@ -40,7 +40,7 @@
#include "Strings.hrc"
#include <toolkit/helper/vclunohelper.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>
#include <com/sun/star/chart2/XChartDocument.hpp>
diff --git a/chart2/source/controller/main/SelectionHelper.cxx b/chart2/source/controller/main/SelectionHelper.cxx
index 5440a8c..6cd6218 100644
--- a/chart2/source/controller/main/SelectionHelper.cxx
+++ b/chart2/source/controller/main/SelectionHelper.cxx
@@ -42,7 +42,7 @@
// header for class SdrPathObj
#include <svx/svdopath.hxx>
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <basegfx/point/b2dpoint.hxx>
#include <com/sun/star/beans/XPropertySet.hpp>
diff --git a/chart2/source/controller/main/ShapeController.cxx b/chart2/source/controller/main/ShapeController.cxx
index 9735a87..cfc7f22 100644
--- a/chart2/source/controller/main/ShapeController.cxx
+++ b/chart2/source/controller/main/ShapeController.cxx
@@ -41,7 +41,7 @@
#include <com/sun/star/frame/XStorable.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/msgbox.hxx>
#include <vcl/svapp.hxx>
#include <editeng/brkitem.hxx>
diff --git a/chart2/source/controller/main/ShapeToolbarController.cxx b/chart2/source/controller/main/ShapeToolbarController.cxx
index 8f5424a..0bb3e3c 100644
--- a/chart2/source/controller/main/ShapeToolbarController.cxx
+++ b/chart2/source/controller/main/ShapeToolbarController.cxx
@@ -31,7 +31,7 @@
#include "ShapeToolbarController.hxx"
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <comphelper/sequence.hxx>
#include <vcl/svapp.hxx>
#include <vcl/toolbox.hxx>
diff --git a/chart2/source/controller/main/UndoCommandDispatch.cxx b/chart2/source/controller/main/UndoCommandDispatch.cxx
index 556c8c0..e53bac4 100644
--- a/chart2/source/controller/main/UndoCommandDispatch.cxx
+++ b/chart2/source/controller/main/UndoCommandDispatch.cxx
@@ -35,7 +35,7 @@
#include <com/sun/star/chart2/XUndoSupplier.hpp>
#include <com/sun/star/util/XModifyBroadcaster.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>
// for ressource strings STR_UNDO and STR_REDO
diff --git a/chart2/source/view/main/ChartView.cxx b/chart2/source/view/main/ChartView.cxx
index 3c5e99b..b358f44 100644
--- a/chart2/source/view/main/ChartView.cxx
+++ b/chart2/source/view/main/ChartView.cxx
@@ -71,7 +71,7 @@
#include <svx/unoshape.hxx>
// header for class Application
#include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <svx/unofill.hxx>
#include <time.h>
diff --git a/sc/inc/refreshtimer.hxx b/sc/inc/refreshtimer.hxx
index 51a7e52..b81e58a 100644
--- a/sc/inc/refreshtimer.hxx
+++ b/sc/inc/refreshtimer.hxx
@@ -30,7 +30,7 @@
#include <tools/list.hxx>
#include <vcl/timer.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <scdllapi.h>
#define SC_REFRESHTIMER_CONTROL_LIST 0
@@ -42,8 +42,8 @@ DECLARE_LIST( ScRefreshTimerList, ScRefreshTimer* )
class ScRefreshTimerControl
{
private:
- ::vos::OMutex aMutex;
- USHORT nBlockRefresh;
+ ::osl::Mutex aMutex;
+ USHORT nBlockRefresh;
public:
#if SC_REFRESHTIMER_CONTROL_LIST
@@ -60,7 +60,7 @@ public:
++nBlockRefresh;
}
BOOL IsRefreshAllowed() const { return !nBlockRefresh; }
- ::vos::OMutex& GetMutex() { return aMutex; }
+ ::osl::Mutex& GetMutex() { return aMutex; }
};
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index 46a0720..e4de303 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -770,7 +770,7 @@ void ScDocument::RemoveUnoObject( SfxListener& rObject )
// This check is done after calling EndListening, so a later BroadcastUno call
// won't touch this object.
- vos::IMutex& rSolarMutex = Application::GetSolarMutex();
+ osl::SolarMutex& rSolarMutex = Application::GetSolarMutex();
if ( rSolarMutex.tryToAcquire() )
{
// BroadcastUno is always called with the SolarMutex locked, so if it
diff --git a/sc/source/core/tool/refreshtimer.cxx b/sc/source/core/tool/refreshtimer.cxx
index 1d70622..5d890a9 100644
--- a/sc/source/core/tool/refreshtimer.cxx
+++ b/sc/source/core/tool/refreshtimer.cxx
@@ -42,7 +42,7 @@ ScRefreshTimerProtector::ScRefreshTimerProtector( ScRefreshTimerControl * const
{
(*ppControl)->SetAllowRefresh( FALSE );
// wait for any running refresh in another thread to finnish
- ::vos::OGuard aGuard( (*ppControl)->GetMutex() );
+ ::osl::MutexGuard aGuard( (*ppControl)->GetMutex() );
}
}
@@ -71,7 +71,7 @@ void ScRefreshTimer::Timeout()
if ( ppControl && *ppControl && (*ppControl)->IsRefreshAllowed() )
{
// now we COULD make the call in another thread ...
- ::vos::OGuard aGuard( (*ppControl)->GetMutex() );
+ ::osl::MutexGuard aGuard( (*ppControl)->GetMutex() );
maTimeoutHdl.Call( this );
// restart from now on, don't execute immediately again if timed out
// a second time during refresh
diff --git a/sc/source/filter/lotus/lotimpop.cxx b/sc/source/filter/lotus/lotimpop.cxx
index 0b7ed91..1ab94fc 100644
--- a/sc/source/filter/lotus/lotimpop.cxx
+++ b/sc/source/filter/lotus/lotimpop.cxx
@@ -29,7 +29,7 @@
// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sc.hxx"
#include "lotimpop.hxx"
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include "attrib.hxx"
#include "document.hxx"
@@ -49,7 +49,7 @@
#include "lotattr.hxx"
-static NAMESPACE_VOS( OMutex ) aLotImpSemaphore;
+static osl::Mutex aLotImpSemaphore;
ImportLotus::ImportLotus( SvStream& aStream, ScDocument* pDoc, CharSet eQ ) :
diff --git a/sc/source/ui/app/drwtrans.cxx b/sc/source/ui/app/drwtrans.cxx
index 65dd826..c41bd87 100644
--- a/sc/source/ui/app/drwtrans.cxx
+++ b/sc/source/ui/app/drwtrans.cxx
@@ -61,7 +61,7 @@
#include <svl/itempool.hxx>
#include <svl/urlbmk.hxx>
#include <tools/urlobj.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include "drwtrans.hxx"
#include "docsh.hxx"
diff --git a/sc/source/ui/app/transobj.cxx b/sc/source/ui/app/transobj.cxx
index d74abd4..d297821 100644
--- a/sc/source/ui/app/transobj.cxx
+++ b/sc/source/ui/app/transobj.cxx
@@ -47,7 +47,7 @@
#include <sot/storage.hxx>
#include <vcl/svapp.hxx>
#include <vcl/virdev.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <sfx2/app.hxx>
#include <sfx2/docfile.hxx>
diff --git a/sc/source/ui/inc/AccessibleContextBase.hxx b/sc/source/ui/inc/AccessibleContextBase.hxx
index 28f4a6b..005c4b8 100644
--- a/sc/source/ui/inc/AccessibleContextBase.hxx
+++ b/sc/source/ui/inc/AccessibleContextBase.hxx
@@ -41,7 +41,7 @@
#include <com/sun/star/lang/XTypeProvider.hpp>
#include <com/sun/star/lang/XServiceName.hpp>
#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <cppuhelper/interfacecontainer.h>
diff --git a/sc/source/ui/unoobj/scdetect.cxx b/sc/source/ui/unoobj/scdetect.cxx
index 6cc8f83..7e3770c 100644
--- a/sc/source/ui/unoobj/scdetect.cxx
+++ b/sc/source/ui/unoobj/scdetect.cxx
@@ -65,7 +65,7 @@
#include <svl/eitem.hxx>
#include <svl/stritem.hxx>
#include <tools/urlobj.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <svtools/sfxecode.hxx>
#include <svtools/ehdl.hxx>
#include <sot/storinfo.hxx>
diff --git a/sc/source/ui/unoobj/unodoc.cxx b/sc/source/ui/unoobj/unodoc.cxx
index 4917cdd..6fa0a47 100644
--- a/sc/source/ui/unoobj/unodoc.cxx
+++ b/sc/source/ui/unoobj/unodoc.cxx
@@ -37,7 +37,7 @@
#include <com/sun/star/lang/XMultiServiceFactory.hpp>
#include "scmod.hxx"
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>
#include "docsh.hxx"
diff --git a/sc/workben/addin.cxx b/sc/workben/addin.cxx
index 0ca3159..f93ac30 100644
--- a/sc/workben/addin.cxx
+++ b/sc/workben/addin.cxx
@@ -33,7 +33,7 @@
#include <usr/factoryhlp.hxx>
#include <usr/macros.hxx>
#include <usr/reflserv.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>
#include <tools/debug.hxx>
#include <tools/date.hxx>
commit 56a52533d446c89592f838f3b50c97d6b7ff3961
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Fri Oct 15 12:20:01 2010 -0500
merge vosremoval-reference.diff
diff --git a/sc/inc/document.hxx b/sc/inc/document.hxx
index ed78343..9ca0d14 100644
--- a/sc/inc/document.hxx
+++ b/sc/inc/document.hxx
@@ -32,7 +32,7 @@
#include <vcl/prntypes.hxx>
#include <vcl/timer.hxx>
#include <com/sun/star/uno/Reference.hxx>
-#include <vos/ref.hxx>
+#include <rtl/ref.hxx>
#include "scdllapi.h"
#include "table.hxx" // FastGetRowHeight (inline)
#include "rangelst.hxx"
@@ -259,7 +259,7 @@ friend class ScDocRowHeightUpdater;
private:
::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > xServiceManager;
- vos::ORef<ScPoolHelper> xPoolHelper;
+ rtl::Reference<ScPoolHelper> xPoolHelper;
SfxUndoManager* mpUndoManager;
ScFieldEditEngine* pEditEngine; // uses pEditPool from xPoolHelper
@@ -302,7 +302,7 @@ private:
ScChangeViewSettings* pChangeViewSettings;
ScScriptTypeData* pScriptTypeData;
ScRefreshTimerControl* pRefreshTimerControl;
- vos::ORef<SvxForbiddenCharactersTable> xForbiddenCharacters;
+ rtl::Reference<SvxForbiddenCharactersTable> xForbiddenCharacters;
ScFieldEditEngine* pCacheFieldEditEngine;
@@ -1587,8 +1587,8 @@ public:
ScChangeViewSettings* GetChangeViewSettings() const { return pChangeViewSettings; }
SC_DLLPUBLIC void SetChangeViewSettings(const ScChangeViewSettings& rNew);
- vos::ORef<SvxForbiddenCharactersTable> GetForbiddenCharacters();
- void SetForbiddenCharacters( const vos::ORef<SvxForbiddenCharactersTable> xNew );
+ rtl::Reference<SvxForbiddenCharactersTable> GetForbiddenCharacters();
+ void SetForbiddenCharacters( const rtl::Reference<SvxForbiddenCharactersTable> xNew );
BYTE GetAsianCompression() const; // CharacterCompressionType values
BOOL IsValidAsianCompression() const;
diff --git a/sc/source/core/data/documen2.cxx b/sc/source/core/data/documen2.cxx
index 73b1cab..7438362 100644
--- a/sc/source/core/data/documen2.cxx
+++ b/sc/source/core/data/documen2.cxx
@@ -455,9 +455,9 @@ ScDocument::~ScDocument()
// delete the EditEngine before destroying the xPoolHelper
delete pCacheFieldEditEngine;
- if ( xPoolHelper.isValid() && !bIsClip )
+ if ( xPoolHelper.is() && !bIsClip )
xPoolHelper->SourceDocumentGone();
- xPoolHelper.unbind();
+ xPoolHelper.clear();
DeleteColorTable();
delete pScriptTypeData;
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index b1c41e9..46a0720 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -1904,7 +1904,7 @@ void ScDocument::SetLanguage( LanguageType eLatin, LanguageType eCjk, LanguageTy
eLanguage = eLatin;
eCjkLanguage = eCjk;
eCtlLanguage = eCtl;
- if ( xPoolHelper.isValid() )
+ if ( xPoolHelper.is() )
{
ScDocumentPool* pPool = xPoolHelper->GetDocPool();
pPool->SetPoolDefaultItem( SvxLanguageItem( eLanguage, ATTR_FONT_LANGUAGE ) );
diff --git a/sc/source/core/data/documen9.cxx b/sc/source/core/data/documen9.cxx
index 2a1eae3..af7e762 100644
--- a/sc/source/core/data/documen9.cxx
+++ b/sc/source/core/data/documen9.cxx
@@ -713,12 +713,12 @@ void ScDocument::SetXMLFromWrapper( BOOL bVal )
bXMLFromWrapper = bVal;
}
-vos::ORef<SvxForbiddenCharactersTable> ScDocument::GetForbiddenCharacters()
+rtl::Reference<SvxForbiddenCharactersTable> ScDocument::GetForbiddenCharacters()
{
return xForbiddenCharacters;
}
-void ScDocument::SetForbiddenCharacters( const vos::ORef<SvxForbiddenCharactersTable> xNew )
+void ScDocument::SetForbiddenCharacters( const rtl::Reference<SvxForbiddenCharactersTable> xNew )
{
xForbiddenCharacters = xNew;
if ( pEditEngine )
diff --git a/sc/source/core/data/document.cxx b/sc/source/core/data/document.cxx
index efde324..2a66a64 100644
--- a/sc/source/core/data/document.cxx
+++ b/sc/source/core/data/document.cxx
@@ -1951,7 +1951,7 @@ void ScDocument::SetClipParam(const ScClipParam& rParam)
BOOL ScDocument::IsClipboardSource() const
{
ScDocument* pClipDoc = SC_MOD()->GetClipDoc();
- return pClipDoc && pClipDoc->xPoolHelper.isValid() &&
+ return pClipDoc && pClipDoc->xPoolHelper.is() &&
xPoolHelper->GetDocPool() == pClipDoc->xPoolHelper->GetDocPool();
}
diff --git a/sc/source/core/inc/poolhelp.hxx b/sc/source/core/inc/poolhelp.hxx
index bfc024f..4f8bed6 100644
--- a/sc/source/core/inc/poolhelp.hxx
+++ b/sc/source/core/inc/poolhelp.hxx
@@ -29,7 +29,7 @@
#define SC_POOLHELP_HXX
#include <rtl/ref.hxx>
-#include <vos/refernce.hxx>
+#include <salhelper/simplereferenceobject.hxx>
#include <tools/link.hxx>
#include "docoptio.hxx"
@@ -40,7 +40,7 @@ class SvNumberFormatter;
class SfxItemPool;
-class ScPoolHelper : public vos::OReference
+class ScPoolHelper : public salhelper::SimpleReferenceObject
{
private:
ScDocOptions aOpt;
diff --git a/sc/source/filter/inc/filt_pch.hxx b/sc/source/filter/inc/filt_pch.hxx
index 484cdb8..1fc2fdb 100644
--- a/sc/source/filter/inc/filt_pch.hxx
+++ b/sc/source/filter/inc/filt_pch.hxx
@@ -222,7 +222,7 @@
#include <vcl/svapp.hxx>
#include <osl/thread.hxx>
#include <vos/runnable.hxx>
-#include <vos/refernce.hxx>
+#include <salhelper/simplereferenceobject.hxx>
#include <vcl/apptypes.hxx>
#include <editeng/editdata.hxx>
#include <editeng/editeng.hxx>
diff --git a/sc/source/filter/xml/XMLDDELinksContext.cxx b/sc/source/filter/xml/XMLDDELinksContext.cxx
index 12ae9ce..269861a 100644
--- a/sc/source/filter/xml/XMLDDELinksContext.cxx
+++ b/sc/source/filter/xml/XMLDDELinksContext.cxx
@@ -46,6 +46,8 @@ using namespace com::sun::star;
using namespace xmloff::token;
using ::rtl::OUString;
+using rtl::OUString;
+
//------------------------------------------------------------------
ScXMLDDELinksContext::ScXMLDDELinksContext( ScXMLImport& rImport,
diff --git a/sc/source/filter/xml/XMLTableHeaderFooterContext.cxx b/sc/source/filter/xml/XMLTableHeaderFooterContext.cxx
index 22f4a8c..80abe62 100644
--- a/sc/source/filter/xml/XMLTableHeaderFooterContext.cxx
+++ b/sc/source/filter/xml/XMLTableHeaderFooterContext.cxx
@@ -45,6 +45,7 @@ using namespace ::com::sun::star::text;
using namespace ::com::sun::star::beans;
using namespace xmloff::token;
+using rtl::OUString;
TYPEINIT1( XMLTableHeaderFooterContext, SvXMLImportContext );
diff --git a/sc/source/filter/xml/XMLTableShapeImportHelper.cxx b/sc/source/filter/xml/XMLTableShapeImportHelper.cxx
index f8c1814..320681e 100644
--- a/sc/source/filter/xml/XMLTableShapeImportHelper.cxx
+++ b/sc/source/filter/xml/XMLTableShapeImportHelper.cxx
@@ -51,6 +51,8 @@ using namespace ::com::sun::star;
using namespace xmloff::token;
using ::rtl::OUString;
+using rtl::OUString;
+
XMLTableShapeImportHelper::XMLTableShapeImportHelper(
ScXMLImport& rImp, SvXMLImportPropertyMapper *pImpMapper ) :
XMLShapeImportHelper(rImp, rImp.GetModel(), pImpMapper ),
diff --git a/sc/source/filter/xml/XMLTrackedChangesContext.cxx b/sc/source/filter/xml/XMLTrackedChangesContext.cxx
index 07f4980..40ae211 100644
--- a/sc/source/filter/xml/XMLTrackedChangesContext.cxx
+++ b/sc/source/filter/xml/XMLTrackedChangesContext.cxx
@@ -48,6 +48,8 @@ using rtl::OUString;
using namespace com::sun::star;
using namespace xmloff::token;
+using rtl::OUString;
+
//-----------------------------------------------------------------------------
class ScXMLChangeInfoContext : public SvXMLImportContext
diff --git a/sc/source/filter/xml/sheetdata.cxx b/sc/source/filter/xml/sheetdata.cxx
index 0e61628..e81ddae 100644
--- a/sc/source/filter/xml/sheetdata.cxx
+++ b/sc/source/filter/xml/sheetdata.cxx
@@ -209,7 +209,7 @@ void ScSheetSaveData::StoreLoadedNamespaces( const SvXMLNamespaceMap& rNamespace
// ignore the initial namespaces
if ( maInitialPrefixes.find( aIter->first ) == maInitialPrefixes.end() )
{
- const NameSpaceEntry& rEntry = aIter->second.getBody();
+ const NameSpaceEntry& rEntry = *(aIter->second);
maLoadedNamespaces.push_back( ScLoadedNamespaceEntry( rEntry.sPrefix, rEntry.sName, rEntry.nKey ) );
}
++aIter;
diff --git a/sc/source/filter/xml/xmlcelli.cxx b/sc/source/filter/xml/xmlcelli.cxx
index 31acb54..35f78f7 100644
--- a/sc/source/filter/xml/xmlcelli.cxx
+++ b/sc/source/filter/xml/xmlcelli.cxx
@@ -97,6 +97,8 @@
using namespace com::sun::star;
using namespace xmloff::token;
+using rtl::OUString;
+
//------------------------------------------------------------------
ScXMLTableRowCellContext::ScXMLTableRowCellContext( ScXMLImport& rImport,
diff --git a/sc/source/filter/xml/xmldpimp.cxx b/sc/source/filter/xml/xmldpimp.cxx
index 5d46d99..d515637 100644
--- a/sc/source/filter/xml/xmldpimp.cxx
+++ b/sc/source/filter/xml/xmldpimp.cxx
@@ -66,6 +66,8 @@ using ::com::sun::star::uno::Reference;
using ::com::sun::star::xml::sax::XAttributeList;
using ::rtl::OUString;
+using rtl::OUString;
+
//------------------------------------------------------------------
ScXMLDataPilotTablesContext::ScXMLDataPilotTablesContext( ScXMLImport& rImport,
diff --git a/sc/source/filter/xml/xmlimprt.cxx b/sc/source/filter/xml/xmlimprt.cxx
index 612fd8c..0c98142 100644
--- a/sc/source/filter/xml/xmlimprt.cxx
+++ b/sc/source/filter/xml/xmlimprt.cxx
@@ -108,6 +108,8 @@ using namespace ::xmloff::token;
using namespace ::formula;
using ::rtl::OUString;
+using rtl::OUString;
+
OUString SAL_CALL ScXMLImport_getImplementationName() throw()
{
return rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Calc.XMLOasisImporter" ) );
diff --git a/sc/source/filter/xml/xmlsceni.cxx b/sc/source/filter/xml/xmlsceni.cxx
index 33d9d29..5e2d19b 100644
--- a/sc/source/filter/xml/xmlsceni.cxx
+++ b/sc/source/filter/xml/xmlsceni.cxx
@@ -50,6 +50,8 @@ using namespace com::sun::star;
using namespace xmloff::token;
using ::rtl::OUString;
+using rtl::OUString;
+
//------------------------------------------------------------------
ScXMLTableScenarioContext::ScXMLTableScenarioContext(
diff --git a/sc/source/filter/xml/xmlstyli.cxx b/sc/source/filter/xml/xmlstyli.cxx
index e8e171d..4e1bd93 100644
--- a/sc/source/filter/xml/xmlstyli.cxx
+++ b/sc/source/filter/xml/xmlstyli.cxx
@@ -78,6 +78,9 @@ using namespace xmloff::token;
//using namespace ::com::sun::star::text;
using namespace ::formula;
+using rtl::OUString;
+using com::sun::star::uno::Reference;
+
ScXMLCellImportPropertyMapper::ScXMLCellImportPropertyMapper(
const UniReference< XMLPropertySetMapper >& rMapper,
SvXMLImport& rImportP) :
diff --git a/sc/source/filter/xml/xmlwrap.cxx b/sc/source/filter/xml/xmlwrap.cxx
index 38ec980..880a147 100644
--- a/sc/source/filter/xml/xmlwrap.cxx
+++ b/sc/source/filter/xml/xmlwrap.cxx
@@ -88,6 +88,8 @@
using namespace com::sun::star;
using ::rtl::OUString;
+using rtl::OUString;
+
// -----------------------------------------------------------------------
ScXMLImportWrapper::ScXMLImportWrapper(ScDocument& rD, SfxMedium* pM, const uno::Reference < embed::XStorage >& xStor ) :
diff --git a/sc/source/ui/docshell/docsh2.cxx b/sc/source/ui/docshell/docsh2.cxx
index 764664f..8686cc7 100644
--- a/sc/source/ui/docshell/docsh2.cxx
+++ b/sc/source/ui/docshell/docsh2.cxx
@@ -179,19 +179,19 @@ void ScDocShell::InitItems()
PutItem( SvxColorTableItem( XColorTable::GetStdColorTable(), SID_COLOR_TABLE ) );
}
- if ( !aDocument.GetForbiddenCharacters().isValid() ||
+ if ( !aDocument.GetForbiddenCharacters().is() ||
!aDocument.IsValidAsianCompression() || !aDocument.IsValidAsianKerning() )
{
// get settings from SvxAsianConfig
SvxAsianConfig aAsian( sal_False );
- if ( !aDocument.GetForbiddenCharacters().isValid() )
+ if ( !aDocument.GetForbiddenCharacters().is() )
{
// set forbidden characters if necessary
uno::Sequence<lang::Locale> aLocales = aAsian.GetStartEndCharLocales();
if (aLocales.getLength())
{
- vos::ORef<SvxForbiddenCharactersTable> xForbiddenTable =
+ rtl::Reference<SvxForbiddenCharactersTable> xForbiddenTable =
new SvxForbiddenCharactersTable( aDocument.GetServiceManager() );
const lang::Locale* pLocales = aLocales.getConstArray();
diff --git a/sc/source/ui/unoobj/forbiuno.cxx b/sc/source/ui/unoobj/forbiuno.cxx
index 50335b1..c6a91c2 100644
--- a/sc/source/ui/unoobj/forbiuno.cxx
+++ b/sc/source/ui/unoobj/forbiuno.cxx
@@ -40,14 +40,14 @@ using namespace ::com::sun::star;
//------------------------------------------------------------------------
-vos::ORef<SvxForbiddenCharactersTable> lcl_GetForbidden( ScDocShell* pDocSh )
+rtl::Reference<SvxForbiddenCharactersTable> lcl_GetForbidden( ScDocShell* pDocSh )
{
- vos::ORef<SvxForbiddenCharactersTable> xRet;
+ rtl::Reference<SvxForbiddenCharactersTable> xRet;
if ( pDocSh )
{
ScDocument* pDoc = pDocSh->GetDocument();
xRet = pDoc->GetForbiddenCharacters();
- if ( !xRet.isValid() )
+ if ( !xRet.is() )
{
// create an empty SvxForbiddenCharactersTable for SvxUnoForbiddenCharsTable,
// so changes can be stored.
diff --git a/sc/util/makefile.mk b/sc/util/makefile.mk
index 71c05ab..c6c2abc 100644
--- a/sc/util/makefile.mk
+++ b/sc/util/makefile.mk
@@ -88,6 +88,7 @@ SHL1STDLIBS= \
$(TKLIB) \
$(VOSLIB) \
$(SALLIB) \
+ $(SALHELPERLIB) \
$(TOOLSLIB) \
$(I18NISOLANGLIB) \
$(UNOTOOLSLIB) \
commit e8c6a8e214441ac19a4e39511c757c8085c89366
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Thu Oct 14 22:22:13 2010 -0500
Use a SolarMutexGuard rather that direct acquire/release on the SolarMutex
diff --git a/sc/source/ui/app/drwtrans.cxx b/sc/source/ui/app/drwtrans.cxx
index 647e0f4..65dd826 100644
--- a/sc/source/ui/app/drwtrans.cxx
+++ b/sc/source/ui/app/drwtrans.cxx
@@ -244,7 +244,7 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
ScDrawTransferObj::~ScDrawTransferObj()
{
- Application::GetSolarMutex().acquire(); //! ???
+ SolarMutexGuard aSolarGuard;
ScModule* pScMod = SC_MOD();
if ( pScMod->GetClipData().pDrawClipboard == this )
@@ -266,8 +266,6 @@ ScDrawTransferObj::~ScDrawTransferObj()
delete pBookmark;
delete pDragSourceView;
-
- Application::GetSolarMutex().release(); //! ???
}
// static
diff --git a/sc/source/ui/app/transobj.cxx b/sc/source/ui/app/transobj.cxx
index c80496a..d74abd4 100644
--- a/sc/source/ui/app/transobj.cxx
+++ b/sc/source/ui/app/transobj.cxx
@@ -194,7 +194,7 @@ ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDesc
ScTransferObj::~ScTransferObj()
{
- Application::GetSolarMutex().acquire();
+ SolarMutexGuard aSolarGuard;
ScModule* pScMod = SC_MOD();
if ( pScMod->GetClipData().pCellClipboard == this )
@@ -214,7 +214,6 @@ ScTransferObj::~ScTransferObj()
aDrawPersistRef.Clear(); // after the model
- Application::GetSolarMutex().release();
}
// static
commit f272c0cca18856f6fe1d8213314d581f3f77e1ba
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Thu Oct 14 22:20:56 2010 -0500
Replace a suspicious Guard on a solar mutex.
This site use a OClearableGuard that is being converted to a SolarMutexGuard
Guard will do... What is suspicious is the point where it is cleared.
It seems that it is way to early to serve its declared purpose.
diff --git a/chart2/source/controller/main/ChartController.cxx b/chart2/source/controller/main/ChartController.cxx
index ee5daa5..3b8c4b9 100644
--- a/chart2/source/controller/main/ChartController.cxx
+++ b/chart2/source/controller/main/ChartController.cxx
@@ -532,10 +532,14 @@ void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent
//is called to attach the controller to a new model.
//return true if attach was successfully, false otherwise (e.g. if you do not work with a model)
- ::vos::OClearableGuard aGuard( Application::GetSolarMutex());
- if( impl_isDisposedOrSuspended() ) //@todo? allow attaching a new model while suspended?
- return sal_False; //behave passive if already disposed or suspended
- aGuard.clear();
+ {
+ // FIXME: ths is suspicious: why just proctect the call to isDisposedOrSuspened
+ // and not all the way until he new model is attached ?
+ // seems racy to me
+ SolarMutexGuard aGuard;
+ if( impl_isDisposedOrSuspended() ) //@todo? allow attaching a new model while suspended?
+ return sal_False; //behave passive if already disposed or suspended
+ }
TheModelRef aNewModelRef( new TheModel( xModel), m_aModelMutex);
commit 5a1c98320a53b37ae53c3e1ef6ddddbfe4f75de3
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date: Thu Oct 14 22:18:02 2010 -0500
replace ScUnoGuard by SolarMutexGuard
ScUnoGaurd provide a Guard wrapper around Application::GetSolarMutex().
This is now provided by the class SolarMutexGuard.
diff --git a/sc/inc/unoguard.hxx b/sc/inc/unoguard.hxx
deleted file mode 100644
index 4c83f3c..0000000
--- a/sc/inc/unoguard.hxx
+++ /dev/null
@@ -1,42 +0,0 @@
-/*************************************************************************
- *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
- *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org. If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-#ifndef SC_UNOGUARD_HXX
-#define SC_UNOGUARD_HXX
-
-#include <vos/mutex.hxx>
-
-class ScUnoGuard : public NAMESPACE_VOS(OGuard)
-{
-public:
- ScUnoGuard();
- ~ScUnoGuard() {}
-};
-
-
-#endif
-
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index e18535e..b1c41e9 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -74,7 +74,6 @@
#include "sc.hrc" // SID_LINK
#include "hints.hxx"
#include "dpobject.hxx"
-#include "unoguard.hxx"
#include "drwlayer.hxx"
#include "unoreflist.hxx"
#include "listenercalls.hxx"
diff --git a/sc/source/core/data/dptabsrc.cxx b/sc/source/core/data/dptabsrc.cxx
index 82d3873..f6ef0df 100644
--- a/sc/source/core/data/dptabsrc.cxx
+++ b/sc/source/core/data/dptabsrc.cxx
@@ -44,6 +44,7 @@
#include <rtl/math.hxx>
#include <svl/itemprop.hxx>
#include <svl/intitem.hxx>
+#include <vcl/svapp.hxx>
#include "scitems.hxx"
#include "document.hxx"
@@ -57,7 +58,6 @@
#include "global.hxx"
#include "collect.hxx"
#include "datauno.hxx" // ScDataUnoConversion
-#include "unoguard.hxx"
#include "miscuno.hxx"
#include "unonames.hxx"
@@ -1141,7 +1141,7 @@ const uno::Sequence<sheet::MemberResult>* ScDPSource::GetMemberResults( ScDPLeve
uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPSource::getPropertySetInfo()
throw(uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
using beans::PropertyAttribute::READONLY;
static SfxItemPropertyMapEntry aDPSourceMap_Impl[] =
@@ -1554,7 +1554,7 @@ BOOL ScDPDimension::IsVisible( const ScDPItemData& rData )
uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPDimension::getPropertySetInfo()
throw(uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
static SfxItemPropertyMapEntry aDPDimensionMap_Impl[] =
{
@@ -2289,7 +2289,7 @@ void ScDPLevel::setShowEmpty(BOOL bSet)
uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPLevel::getPropertySetInfo()
throw(uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
static SfxItemPropertyMapEntry aDPLevelMap_Impl[] =
{
@@ -2794,7 +2794,7 @@ void ScDPMember::setPosition(sal_Int32 nNew)
uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPMember::getPropertySetInfo()
throw(uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
static SfxItemPropertyMapEntry aDPMemberMap_Impl[] =
{
diff --git a/sc/source/core/tool/addinlis.cxx b/sc/source/core/tool/addinlis.cxx
index a892b0d..6f5cd1a 100644
--- a/sc/source/core/tool/addinlis.cxx
+++ b/sc/source/core/tool/addinlis.cxx
@@ -33,13 +33,13 @@
#include <tools/debug.hxx>
#include <sfx2/objsh.hxx>
+#include <vcl/svapp.hxx>
#include "addinlis.hxx"
#include "miscuno.hxx" // SC_IMPL_SERVICE_INFO
#include "document.hxx"
#include "brdcst.hxx"
-#include "unoguard.hxx"
#include "sc.hrc"
using namespace com::sun::star;
@@ -136,7 +136,7 @@ void ScAddInListener::RemoveDocument( ScDocument* pDocumentP )
void SAL_CALL ScAddInListener::modified( const ::com::sun::star::sheet::ResultEvent& aEvent )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard; //! or generate a UserEvent
+ SolarMutexGuard aGuard; //! or generate a UserEvent
aResult = aEvent.Value; // store result
diff --git a/sc/source/filter/xml/xmlexprt.cxx b/sc/source/filter/xml/xmlexprt.cxx
index dcdd431..1430be8 100644
--- a/sc/source/filter/xml/xmlexprt.cxx
+++ b/sc/source/filter/xml/xmlexprt.cxx
@@ -58,7 +58,6 @@
#include "docuno.hxx"
#include "textuno.hxx"
#include "chartlis.hxx"
-#include "unoguard.hxx"
#include "scitems.hxx"
#include "docpool.hxx"
#include "userdat.hxx"
@@ -4459,7 +4458,7 @@ sal_uInt32 ScXMLExport::exportDoc( enum XMLTokenEnum eClass )
void SAL_CALL ScXMLExport::setSourceDocument( const uno::Reference<lang::XComponent>& xComponent )
throw(lang::IllegalArgumentException, uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
SvXMLExport::setSourceDocument( xComponent );
pDoc = ScXMLConverter::GetScDocument( GetModel() );
@@ -4489,7 +4488,7 @@ void SAL_CALL ScXMLExport::setSourceDocument( const uno::Reference<lang::XCompon
sal_Bool SAL_CALL ScXMLExport::filter( const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aDescriptor )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (pDoc)
pDoc->DisableIdle(TRUE);
sal_Bool bReturn(SvXMLExport::filter(aDescriptor));
@@ -4501,7 +4500,7 @@ sal_Bool SAL_CALL ScXMLExport::filter( const ::com::sun::star::uno::Sequence< ::
void SAL_CALL ScXMLExport::cancel()
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (pDoc)
pDoc->DisableIdle(FALSE);
SvXMLExport::cancel();
@@ -4511,7 +4510,7 @@ void SAL_CALL ScXMLExport::cancel()
void SAL_CALL ScXMLExport::initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& aArguments )
throw(::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
SvXMLExport::initialize(aArguments);
}
@@ -4519,7 +4518,7 @@ void SAL_CALL ScXMLExport::initialize( const ::com::sun::star::uno::Sequence< ::
::rtl::OUString SAL_CALL ScXMLExport::getImplementationName( )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
sal_uInt16 nFlags = getExportFlags();
if (nFlags & EXPORT_OASIS)
@@ -4567,14 +4566,14 @@ void SAL_CALL ScXMLExport::initialize( const ::com::sun::star::uno::Sequence< ::
sal_Bool SAL_CALL ScXMLExport::supportsService( const ::rtl::OUString& ServiceName )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
return SvXMLExport::supportsService( ServiceName );
}
::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL ScXMLExport::getSupportedServiceNames( )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
return SvXMLExport::getSupportedServiceNames();
}
@@ -4582,7 +4581,7 @@ sal_Bool SAL_CALL ScXMLExport::supportsService( const ::rtl::OUString& ServiceNa
sal_Int64 SAL_CALL ScXMLExport::getSomething( const ::com::sun::star::uno::Sequence< sal_Int8 >& aIdentifier )
throw(::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
return SvXMLExport::getSomething(aIdentifier);
}
diff --git a/sc/source/filter/xml/xmlimprt.hxx b/sc/source/filter/xml/xmlimprt.hxx
index 472904f..b515394 100644
--- a/sc/source/filter/xml/xmlimprt.hxx
+++ b/sc/source/filter/xml/xmlimprt.hxx
@@ -609,7 +609,7 @@ class SfxItemSet;
class SvXMLNumFmtHelper;
class XMLShapeImportHelper;
class ScXMLChangeTrackingImportHelper;
-class ScUnoGuard;
+class SolarMutexGuard;
struct tScMyCellRange
{
@@ -767,7 +767,7 @@ class ScXMLImport: public SvXMLImport
ScMyLabelRanges* pMyLabelRanges;
ScMyImportValidations* pValidations;
ScMyImpDetectiveOpArray* pDetectiveOpArray;
- ScUnoGuard* pScUnoGuard;
+ SolarMutexGuard* pSolarMutexGuard;
std::vector<rtl::OUString> aTableStyles;
XMLNumberFormatAttributesExportHelper* pNumberFormatAttributesExportHelper;
diff --git a/sc/source/ui/Accessibility/AccessibleCell.cxx b/sc/source/ui/Accessibility/AccessibleCell.cxx
index 558e9c3..79f9957 100644
--- a/sc/source/ui/Accessibility/AccessibleCell.cxx
+++ b/sc/source/ui/Accessibility/AccessibleCell.cxx
@@ -41,7 +41,6 @@
#include "document.hxx"
#include "attrib.hxx"
#include "miscuno.hxx"
-#include "unoguard.hxx"
#include "editsrc.hxx"
#include "dociter.hxx"
#include "cell.hxx"
@@ -56,6 +55,7 @@
#include <editeng/brshitem.hxx>
#include <comphelper/sequence.hxx>
#include <float.h>
+#include <vcl/svapp.hxx>
using namespace ::com::sun::star;
using namespace ::com::sun::star::accessibility;
@@ -100,7 +100,7 @@ void ScAccessibleCell::Init()
void SAL_CALL ScAccessibleCell::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
// #100593# dispose in AccessibleStaticTextBase
Dispose();
@@ -134,7 +134,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleCell::getAccessibleAtPoint(
void SAL_CALL ScAccessibleCell::grabFocus( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (getAccessibleParent().is() && mpViewShell)
{
@@ -227,7 +227,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
ScAccessibleCell::getAccessibleStateSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
uno::Reference<XAccessibleStateSet> xParentStates;
if (getAccessibleParent().is())
{
@@ -265,7 +265,7 @@ uno::Reference<XAccessibleRelationSet> SAL_CALL
ScAccessibleCell::getAccessibleRelationSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
utl::AccessibleRelationSetHelper* pRelationSet = NULL;
if (mpAccDoc)
diff --git a/sc/source/ui/Accessibility/AccessibleCellBase.cxx b/sc/source/ui/Accessibility/AccessibleCellBase.cxx
index 9fe97ea..1ba7938 100644
--- a/sc/source/ui/Accessibility/AccessibleCellBase.cxx
+++ b/sc/source/ui/Accessibility/AccessibleCellBase.cxx
@@ -37,7 +37,6 @@
#include "document.hxx"
#include "docfunc.hxx"
#include "cell.hxx"
-#include "unoguard.hxx"
#include "scresid.hxx"
#include "sc.hrc"
#include "unonames.hxx"
@@ -51,6 +50,7 @@
#include <rtl/uuid.h>
#include <comphelper/sequence.hxx>
#include <sfx2/objsh.hxx>
+#include <vcl/svapp.hxx>
#include <float.h>
@@ -81,7 +81,7 @@ ScAccessibleCellBase::~ScAccessibleCellBase()
sal_Bool SAL_CALL ScAccessibleCellBase::isVisible( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
// test whether the cell is hidden (column/row - hidden/filtered)
sal_Bool bVisible(sal_True);
@@ -101,7 +101,7 @@ sal_Bool SAL_CALL ScAccessibleCellBase::isVisible( )
sal_Int32 SAL_CALL ScAccessibleCellBase::getForeground()
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
if (mpDoc)
@@ -141,7 +141,7 @@ sal_Int32 SAL_CALL ScAccessibleCellBase::getForeground()
sal_Int32 SAL_CALL ScAccessibleCellBase::getBackground()
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
@@ -207,7 +207,7 @@ sal_Int32
ScAccessibleCellBase::getAccessibleIndexInParent(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return mnIndex;
}
@@ -244,7 +244,7 @@ uno::Any SAL_CALL
ScAccessibleCellBase::getCurrentValue( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
uno::Any aAny;
if (mpDoc)
@@ -257,7 +257,7 @@ sal_Bool SAL_CALL
ScAccessibleCellBase::setCurrentValue( const uno::Any& aNumber )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
double fValue = 0;
sal_Bool bResult(sal_False);
@@ -319,7 +319,7 @@ uno::Sequence<sal_Int8> SAL_CALL
ScAccessibleCellBase::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
diff --git a/sc/source/ui/Accessibility/AccessibleContextBase.cxx b/sc/source/ui/Accessibility/AccessibleContextBase.cxx
index d90626a..da20759 100644
--- a/sc/source/ui/Accessibility/AccessibleContextBase.cxx
+++ b/sc/source/ui/Accessibility/AccessibleContextBase.cxx
@@ -31,7 +31,6 @@
#include "AccessibleContextBase.hxx"
-#include "unoguard.hxx"
#include <com/sun/star/accessibility/AccessibleRole.hpp>
#include <com/sun/star/accessibility/AccessibleEventId.hpp>
#include <com/sun/star/accessibility/AccessibleStateType.hpp>
@@ -47,6 +46,7 @@
#include <vcl/unohelp.hxx>
#include <tools/color.hxx>
#include <comphelper/accessibleeventnotifier.hxx>
+#include <vcl/svapp.hxx>
using namespace ::rtl;
using namespace ::com::sun::star;
@@ -99,7 +99,7 @@ void ScAccessibleContextBase::Init()
void SAL_CALL ScAccessibleContextBase::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
// CommitDefunc(); not necessary and should not be send, because it cost a lot of time
// hold reference to make sure that the destructor is not called
@@ -173,7 +173,7 @@ uno::Reference< XAccessibleContext> SAL_CALL
sal_Bool SAL_CALL ScAccessibleContextBase::containsPoint(const awt::Point& rPoint )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return Rectangle (Point(), GetBoundingBox().GetSize()).IsInside(VCLPoint(rPoint));
}
@@ -189,7 +189,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleContextBase::getAccessibleAtP
awt::Rectangle SAL_CALL ScAccessibleContextBase::getBounds( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return AWTRectangle(GetBoundingBox());
}
@@ -197,7 +197,7 @@ awt::Rectangle SAL_CALL ScAccessibleContextBase::getBounds( )
awt::Point SAL_CALL ScAccessibleContextBase::getLocation( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return AWTPoint(GetBoundingBox().TopLeft());
}
@@ -205,7 +205,7 @@ awt::Point SAL_CALL ScAccessibleContextBase::getLocation( )
awt::Point SAL_CALL ScAccessibleContextBase::getLocationOnScreen( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return AWTPoint(GetBoundingBoxOnScreen().TopLeft());
}
@@ -213,7 +213,7 @@ awt::Point SAL_CALL ScAccessibleContextBase::getLocationOnScreen( )
awt::Size SAL_CALL ScAccessibleContextBase::getSize( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return AWTSize(GetBoundingBox().GetSize());
}
@@ -221,7 +221,7 @@ awt::Size SAL_CALL ScAccessibleContextBase::getSize( )
sal_Bool SAL_CALL ScAccessibleContextBase::isShowing( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Bool bShowing(sal_False);
if (mxParent.is())
@@ -290,7 +290,7 @@ sal_Int32 SAL_CALL
ScAccessibleContextBase::getAccessibleIndexInParent(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
// Use a simple but slow solution for now. Optimize later.
// Return -1 to indicate that this object's parent does not know about the
@@ -331,7 +331,7 @@ sal_Int16 SAL_CALL
ScAccessibleContextBase::getAccessibleDescription(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (!msDescription.getLength())
{
@@ -358,7 +358,7 @@ OUString SAL_CALL
ScAccessibleContextBase::getAccessibleName(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (!msName.getLength())
{
@@ -400,7 +400,7 @@ lang::Locale SAL_CALL
throw (IllegalAccessibleComponentStateException,
uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mxParent.is())
{
@@ -424,7 +424,7 @@ void SAL_CALL
{
if (xListener.is())
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (!IsDefunc())
{
@@ -442,7 +442,7 @@ void SAL_CALL
{
if (xListener.is())
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (!IsDefunc() && mnClientId)
{
sal_Int32 nListenerCount = comphelper::AccessibleEventNotifier::removeEventListener( mnClientId, xListener );
@@ -465,7 +465,7 @@ void SAL_CALL ScAccessibleContextBase::disposing(
const lang::EventObject& rSource )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (rSource.Source == mxParent)
dispose();
}
@@ -528,7 +528,7 @@ uno::Sequence<sal_Int8> SAL_CALL
ScAccessibleContextBase::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
diff --git a/sc/source/ui/Accessibility/AccessibleCsvControl.cxx b/sc/source/ui/Accessibility/AccessibleCsvControl.cxx
index b7c828e..b682924 100644
--- a/sc/source/ui/Accessibility/AccessibleCsvControl.cxx
+++ b/sc/source/ui/Accessibility/AccessibleCsvControl.cxx
@@ -53,11 +53,11 @@
#include "csvgrid.hxx"
#include "AccessibleText.hxx"
#include "editsrc.hxx"
-#include "unoguard.hxx"
#include "scresid.hxx"
#include "sc.hrc"
#include "scmod.hxx"
#include <svtools/colorcfg.hxx>
+#include <vcl/svapp.hxx>
// ause
#include "editutil.hxx"
@@ -119,7 +119,7 @@ ScAccessibleCsvControl::~ScAccessibleCsvControl()
void SAL_CALL ScAccessibleCsvControl::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
mpControl = NULL;
ScAccessibleContextBase::disposing();
}
@@ -136,14 +136,14 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvControl::getAccessibleAtPoint(
sal_Bool SAL_CALL ScAccessibleCsvControl::isVisible() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetControl().IsVisible();
}
void SAL_CALL ScAccessibleCsvControl::grabFocus() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
implGetControl().GrabFocus();
}
@@ -200,21 +200,21 @@ void ScAccessibleCsvControl::SendRemoveColumnEvent( sal_uInt32 /* nFirstColumn *
Rectangle ScAccessibleCsvControl::GetBoundingBoxOnScreen() const throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetControl().GetWindowExtentsRelative( NULL );
}
Rectangle ScAccessibleCsvControl::GetBoundingBox() const throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetControl().GetWindowExtentsRelative( implGetControl().GetAccessibleParentWindow() );
}
void ScAccessibleCsvControl::getUuid( Sequence< sal_Int8 >& rSeq )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
if( !rSeq.hasElements() )
{
@@ -264,7 +264,7 @@ Reference< XAccessible > ScAccessibleCsvControl::implGetChildByRole(
AccessibleStateSetHelper* ScAccessibleCsvControl::implCreateStateSet()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
AccessibleStateSetHelper* pStateSet = new AccessibleStateSetHelper();
if( implIsAlive() )
{
@@ -390,7 +390,7 @@ ScAccessibleCsvRuler::~ScAccessibleCsvRuler()
sal_Int32 SAL_CALL ScAccessibleCsvRuler::getForeground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetRuler().GetSettings().GetStyleSettings().GetLabelTextColor().GetColor();
}
@@ -398,7 +398,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvRuler::getForeground( )
sal_Int32 SAL_CALL ScAccessibleCsvRuler::getBackground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetRuler().GetSettings().GetStyleSettings().GetFaceColor().GetColor();
}
@@ -421,7 +421,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvRuler::getAccessibleChild( sal_
Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvRuler::getAccessibleRelationSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
AccessibleRelationSetHelper* pRelationSet = new AccessibleRelationSetHelper();
Reference< XAccessible > xAccObj = implGetChildByRole( getAccessibleParent(), nGridRole );
@@ -437,7 +437,7 @@ Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvRuler::getAccessible
Reference< XAccessibleStateSet > SAL_CALL ScAccessibleCsvRuler::getAccessibleStateSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
AccessibleStateSetHelper* pStateSet = implCreateStateSet();
if( implIsAlive() )
{
@@ -454,7 +454,7 @@ Reference< XAccessibleStateSet > SAL_CALL ScAccessibleCsvRuler::getAccessibleSta
sal_Int32 SAL_CALL ScAccessibleCsvRuler::getCaretPosition() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return lcl_GetApiPos( implGetRuler().GetRulerCursorPos() );
}
@@ -462,7 +462,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvRuler::getCaretPosition() throw( RuntimeExcept
sal_Bool SAL_CALL ScAccessibleCsvRuler::setCaretPosition( sal_Int32 nIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nIndex );
ScCsvRuler& rRuler = implGetRuler();
@@ -474,7 +474,7 @@ sal_Bool SAL_CALL ScAccessibleCsvRuler::setCaretPosition( sal_Int32 nIndex )
sal_Unicode SAL_CALL ScAccessibleCsvRuler::getCharacter( sal_Int32 nIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nIndex );
return maBuffer.charAt( nIndex );
@@ -484,7 +484,7 @@ Sequence< PropertyValue > SAL_CALL ScAccessibleCsvRuler::getCharacterAttributes(
const ::com::sun::star::uno::Sequence< ::rtl::OUString >& /* aRequestedAttributes */ )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndexWithEnd( nIndex );
Sequence< PropertyValue > aSeq;
@@ -502,7 +502,7 @@ Sequence< PropertyValue > SAL_CALL ScAccessibleCsvRuler::getCharacterAttributes(
ScAccessibleCsvRuler::AwtRectangle SAL_CALL ScAccessibleCsvRuler::getCharacterBounds( sal_Int32 nIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndexWithEnd( nIndex );
ScCsvRuler& rRuler = implGetRuler();
@@ -519,7 +519,7 @@ ScAccessibleCsvRuler::AwtRectangle SAL_CALL ScAccessibleCsvRuler::getCharacterBo
sal_Int32 SAL_CALL ScAccessibleCsvRuler::getCharacterCount() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetTextLength();
}
@@ -527,7 +527,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvRuler::getCharacterCount() throw( RuntimeExcep
sal_Int32 SAL_CALL ScAccessibleCsvRuler::getIndexAtPoint( const AwtPoint& rPoint )
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ScCsvRuler& rRuler = implGetRuler();
// #107054# use object's coordinate system, convert to API position
@@ -561,7 +561,7 @@ sal_Bool SAL_CALL ScAccessibleCsvRuler::setSelection( sal_Int32 /* nStartIndex *
OUString SAL_CALL ScAccessibleCsvRuler::getText() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return OUString( maBuffer.getStr(), implGetTextLength() );
}
@@ -569,7 +569,7 @@ OUString SAL_CALL ScAccessibleCsvRuler::getText() throw( RuntimeException )
OUString SAL_CALL ScAccessibleCsvRuler::getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidRange( nStartIndex, nEndIndex );
return OUString( maBuffer.getStr() + nStartIndex, nEndIndex - nStartIndex );
@@ -578,7 +578,7 @@ OUString SAL_CALL ScAccessibleCsvRuler::getTextRange( sal_Int32 nStartIndex, sal
TextSegment SAL_CALL ScAccessibleCsvRuler::getTextAtIndex( sal_Int32 nIndex, sal_Int16 nTextType )
throw( IndexOutOfBoundsException, IllegalArgumentException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
TextSegment aResult;
@@ -643,7 +643,7 @@ TextSegment SAL_CALL ScAccessibleCsvRuler::getTextAtIndex( sal_Int32 nIndex, sal
TextSegment SAL_CALL ScAccessibleCsvRuler::getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 nTextType )
throw( IndexOutOfBoundsException, IllegalArgumentException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndexWithEnd( nIndex );
@@ -696,7 +696,7 @@ TextSegment SAL_CALL ScAccessibleCsvRuler::getTextBeforeIndex( sal_Int32 nIndex,
TextSegment SAL_CALL ScAccessibleCsvRuler::getTextBehindIndex( sal_Int32 nIndex, sal_Int16 nTextType )
throw( IndexOutOfBoundsException, IllegalArgumentException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndexWithEnd( nIndex );
@@ -858,7 +858,7 @@ ScCsvRuler& ScAccessibleCsvRuler::implGetRuler() const
void ScAccessibleCsvRuler::constructStringBuffer() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
// extend existing string buffer to new ruler size
sal_Int32 nRulerCount = implGetRuler().GetPosCount();
@@ -943,7 +943,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getAccessibleAtPoint( con
Reference< XAccessible > xRet;
if( containsPoint( rPoint ) )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
const ScCsvGrid& rGrid = implGetGrid();
@@ -960,7 +960,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getAccessibleAtPoint( con
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getForeground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetGrid().GetSettings().GetStyleSettings().GetButtonTextColor().GetColor();
}
@@ -968,7 +968,7 @@ throw (RuntimeException)
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getBackground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return SC_MOD()->GetColorConfig().GetColorValue( ::svtools::DOCCOLOR ).nColor;
}
@@ -977,7 +977,7 @@ throw (RuntimeException)
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleChildCount() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetCellCount();
}
@@ -985,7 +985,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleChildCount() throw( Runtime
Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getAccessibleChild( sal_Int32 nIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nIndex );
return implCreateCellObj( implGetRow( nIndex ), implGetColumn( nIndex ) );
@@ -994,7 +994,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getAccessibleChild( sal_I
Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvGrid::getAccessibleRelationSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
AccessibleRelationSetHelper* pRelationSet = new AccessibleRelationSetHelper();
Reference< XAccessible > xAccObj = implGetChildByRole( getAccessibleParent(), nRulerRole );
@@ -1010,7 +1010,7 @@ Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvGrid::getAccessibleR
Reference< XAccessibleStateSet > SAL_CALL ScAccessibleCsvGrid::getAccessibleStateSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
AccessibleStateSetHelper* pStateSet = implCreateStateSet();
if( implIsAlive() )
{
@@ -1030,14 +1030,14 @@ Reference< XAccessibleStateSet > SAL_CALL ScAccessibleCsvGrid::getAccessibleStat
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleRowCount() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetRowCount();
}
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleColumnCount() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetColumnCount();
}
@@ -1045,7 +1045,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleColumnCount() throw( Runtim
OUString SAL_CALL ScAccessibleCsvGrid::getAccessibleRowDescription( sal_Int32 nRow )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidPosition( nRow, 0 );
return implGetCellText( nRow, 0 );
@@ -1054,7 +1054,7 @@ OUString SAL_CALL ScAccessibleCsvGrid::getAccessibleRowDescription( sal_Int32 nR
OUString SAL_CALL ScAccessibleCsvGrid::getAccessibleColumnDescription( sal_Int32 nColumn )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidPosition( 0, nColumn );
return implGetCellText( 0, nColumn );
@@ -1100,7 +1100,7 @@ Sequence< sal_Int32 > SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleRows()
Sequence< sal_Int32 > SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleColumns()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ScCsvGrid& rGrid = implGetGrid();
@@ -1125,7 +1125,7 @@ sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleRowSelected( sal_Int32 /* nRo
sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleColumnSelected( sal_Int32 nColumn )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nColumn );
return implIsColumnSelected( nColumn );
@@ -1134,7 +1134,7 @@ sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleColumnSelected( sal_Int32 nCo
Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getAccessibleCellAt( sal_Int32 nRow, sal_Int32 nColumn )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidPosition( nRow, nColumn );
return implCreateCellObj( nRow, nColumn );
@@ -1163,7 +1163,7 @@ sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleSelected( sal_Int32 /* nRow *
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleIndex( sal_Int32 nRow, sal_Int32 nColumn )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidPosition( nRow, nColumn );
return implGetIndex( nRow, nColumn );
@@ -1172,7 +1172,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleIndex( sal_Int32 nRow, sal_
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleRow( sal_Int32 nChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nChildIndex );
return implGetRow( nChildIndex );
@@ -1181,7 +1181,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleRow( sal_Int32 nChildIndex
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleColumn( sal_Int32 nChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nChildIndex );
return implGetColumn( nChildIndex );
@@ -1193,7 +1193,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getAccessibleColumn( sal_Int32 nChildInd
void SAL_CALL ScAccessibleCsvGrid::selectAccessibleChild( sal_Int32 nChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nChildIndex );
sal_Int32 nColumn = implGetColumn( nChildIndex );
@@ -1206,7 +1206,7 @@ void SAL_CALL ScAccessibleCsvGrid::selectAccessibleChild( sal_Int32 nChildIndex
sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleChildSelected( sal_Int32 nChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ensureValidIndex( nChildIndex );
sal_Int32 nColumn = implGetColumn( nChildIndex );
@@ -1215,7 +1215,7 @@ sal_Bool SAL_CALL ScAccessibleCsvGrid::isAccessibleChildSelected( sal_Int32 nChi
void SAL_CALL ScAccessibleCsvGrid::clearAccessibleSelection() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
implGetGrid().SelectAll( false );
}
@@ -1227,7 +1227,7 @@ void SAL_CALL ScAccessibleCsvGrid::selectAllAccessibleChildren() throw( RuntimeE
sal_Int32 SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleChildCount() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetRowCount() * implGetSelColumnCount();
}
@@ -1235,7 +1235,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleChildCount() throw(
Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
sal_Int32 nColumns = implGetSelColumnCount();
if( nColumns == 0 )
@@ -1249,7 +1249,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvGrid::getSelectedAccessibleChil
void SAL_CALL ScAccessibleCsvGrid::deselectAccessibleChild( sal_Int32 nSelectedChildIndex )
throw( IndexOutOfBoundsException, RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
sal_Int32 nColumns = implGetSelColumnCount();
if( nColumns == 0 )
@@ -1489,7 +1489,7 @@ ScAccessibleCsvCell::~ScAccessibleCsvCell()
void SAL_CALL ScAccessibleCsvCell::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
SetEditSource( SvxEditSourcePtr( NULL ) );
ScAccessibleCsvControl::disposing();
}
@@ -1499,7 +1499,7 @@ void SAL_CALL ScAccessibleCsvCell::disposing()
void SAL_CALL ScAccessibleCsvCell::grabFocus() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
ScCsvGrid& rGrid = implGetGrid();
rGrid.Execute( CSVCMD_MOVEGRIDCURSOR, rGrid.GetColumnPos( mnColumn ) );
@@ -1508,7 +1508,7 @@ void SAL_CALL ScAccessibleCsvCell::grabFocus() throw( RuntimeException )
sal_Int32 SAL_CALL ScAccessibleCsvCell::getForeground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetGrid().GetSettings().GetStyleSettings().GetButtonTextColor().GetColor();
}
@@ -1516,7 +1516,7 @@ throw (RuntimeException)
sal_Int32 SAL_CALL ScAccessibleCsvCell::getBackground( )
throw (RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return SC_MOD()->GetColorConfig().GetColorValue( ::svtools::DOCCOLOR ).nColor;
}
@@ -1536,7 +1536,7 @@ Reference< XAccessible > SAL_CALL ScAccessibleCsvCell::getAccessibleChild( sal_I
sal_Int32 SAL_CALL ScAccessibleCsvCell::getAccessibleIndexInParent() throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return mnIndex;
}
@@ -1544,7 +1544,7 @@ sal_Int32 SAL_CALL ScAccessibleCsvCell::getAccessibleIndexInParent() throw( Runt
Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvCell::getAccessibleRelationSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return new AccessibleRelationSetHelper();
}
@@ -1552,7 +1552,7 @@ Reference< XAccessibleRelationSet > SAL_CALL ScAccessibleCsvCell::getAccessibleR
Reference< XAccessibleStateSet > SAL_CALL ScAccessibleCsvCell::getAccessibleStateSet()
throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
AccessibleStateSetHelper* pStateSet = implCreateStateSet();
if( implIsAlive() )
{
@@ -1587,7 +1587,7 @@ OUString SAL_CALL ScAccessibleCsvCell::getImplementationName() throw( RuntimeExc
Rectangle ScAccessibleCsvCell::GetBoundingBoxOnScreen() const throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
Rectangle aRect( implGetBoundingBox() );
aRect.SetPos( implGetAbsPos( aRect.TopLeft() ) );
@@ -1596,7 +1596,7 @@ Rectangle ScAccessibleCsvCell::GetBoundingBoxOnScreen() const throw( RuntimeExce
Rectangle ScAccessibleCsvCell::GetBoundingBox() const throw( RuntimeException )
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
ensureAlive();
return implGetBoundingBox();
}
diff --git a/sc/source/ui/Accessibility/AccessibleDataPilotControl.cxx b/sc/source/ui/Accessibility/AccessibleDataPilotControl.cxx
index 0de7fdd..1982234 100644
--- a/sc/source/ui/Accessibility/AccessibleDataPilotControl.cxx
+++ b/sc/source/ui/Accessibility/AccessibleDataPilotControl.cxx
@@ -29,7 +29,6 @@
// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sc.hxx"
#include "AccessibleDataPilotControl.hxx"
-#include "unoguard.hxx"
#include "fieldwnd.hxx"
#include <com/sun/star/accessibility/AccessibleRole.hpp>
@@ -41,6 +40,7 @@
#include <tools/gen.hxx>
#include <toolkit/helper/convert.hxx>
#include <tools/debug.hxx>
+#include <vcl/svapp.hxx>
using namespace ::com::sun::star;
using namespace ::com::sun::star::accessibility;
@@ -179,7 +179,7 @@ void ScAccessibleDataPilotControl::Init()
void SAL_CALL ScAccessibleDataPilotControl::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
mpDPFieldWindow = NULL;
ScAccessibleContextBase::disposing();
@@ -330,7 +330,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleDataPilotControl::getAccessib
uno::Reference<XAccessible> xAcc;
if (containsPoint(rPoint))
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
{
@@ -354,7 +354,7 @@ sal_Bool SAL_CALL ScAccessibleDataPilotControl::isVisible( )
void SAL_CALL ScAccessibleDataPilotControl::grabFocus( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
mpDPFieldWindow->GrabFocus();
@@ -363,7 +363,7 @@ void SAL_CALL ScAccessibleDataPilotControl::grabFocus( )
sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getForeground( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
if (mpDPFieldWindow)
@@ -376,7 +376,7 @@ sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getForeground( )
sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getBackground( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
if (mpDPFieldWindow)
@@ -398,7 +398,7 @@ sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getBackground( )
sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getAccessibleChildCount(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
return mpDPFieldWindow->GetFieldCount();
@@ -409,7 +409,7 @@ sal_Int32 SAL_CALL ScAccessibleDataPilotControl::getAccessibleChildCount(void)
uno::Reference< XAccessible> SAL_CALL ScAccessibleDataPilotControl::getAccessibleChild(sal_Int32 nIndex)
throw (uno::RuntimeException, lang::IndexOutOfBoundsException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
uno::Reference<XAccessible> xAcc;
if (mpDPFieldWindow)
@@ -435,7 +435,7 @@ uno::Reference< XAccessible> SAL_CALL ScAccessibleDataPilotControl::getAccessibl
uno::Reference<XAccessibleStateSet> SAL_CALL ScAccessibleDataPilotControl::getAccessibleStateSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
utl::AccessibleStateSetHelper* pStateSet = new utl::AccessibleStateSetHelper();
@@ -468,7 +468,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL ScAccessibleDataPilotControl::getAc
uno::Sequence<sal_Int8> SAL_CALL ScAccessibleDataPilotControl::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
@@ -484,7 +484,7 @@ uno::Sequence<sal_Int8> SAL_CALL ScAccessibleDataPilotControl::getImplementation
::rtl::OUString SAL_CALL ScAccessibleDataPilotControl::createAccessibleDescription(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
return mpDPFieldWindow->GetDescription();
@@ -495,7 +495,7 @@ uno::Sequence<sal_Int8> SAL_CALL ScAccessibleDataPilotControl::getImplementation
::rtl::OUString SAL_CALL ScAccessibleDataPilotControl::createAccessibleName(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
return mpDPFieldWindow->GetName();
@@ -552,7 +552,7 @@ void ScAccessibleDataPilotButton::Init()
void SAL_CALL ScAccessibleDataPilotButton::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
mpDPFieldWindow = NULL;
ScAccessibleContextBase::disposing();
@@ -586,7 +586,7 @@ sal_Bool SAL_CALL ScAccessibleDataPilotButton::isVisible( )
void SAL_CALL ScAccessibleDataPilotButton::grabFocus( )
throw (::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
{
@@ -597,7 +597,7 @@ void SAL_CALL ScAccessibleDataPilotButton::grabFocus( )
sal_Int32 SAL_CALL ScAccessibleDataPilotButton::getForeground( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
if (mpDPFieldWindow)
@@ -610,7 +610,7 @@ throw (uno::RuntimeException)
sal_Int32 SAL_CALL ScAccessibleDataPilotButton::getBackground( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nColor(0);
if (mpDPFieldWindow)
@@ -638,7 +638,7 @@ uno::Reference< XAccessible> SAL_CALL ScAccessibleDataPilotButton::getAccessible
sal_Int32 SAL_CALL ScAccessibleDataPilotButton::getAccessibleIndexInParent(void)
throw (::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return mnIndex;
}
@@ -646,7 +646,7 @@ sal_Int32 SAL_CALL ScAccessibleDataPilotButton::getAccessibleIndexInParent(void)
uno::Reference<XAccessibleStateSet> SAL_CALL ScAccessibleDataPilotButton::getAccessibleStateSet(void)
throw (::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
utl::AccessibleStateSetHelper* pStateSet = new utl::AccessibleStateSetHelper();
@@ -682,7 +682,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL ScAccessibleDataPilotButton::getAcc
uno::Sequence<sal_Int8> SAL_CALL ScAccessibleDataPilotButton::getImplementationId(void)
throw (::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
@@ -702,7 +702,7 @@ uno::Sequence<sal_Int8> SAL_CALL ScAccessibleDataPilotButton::getImplementationI
::rtl::OUString SAL_CALL ScAccessibleDataPilotButton::createAccessibleName(void)
throw (::com::sun::star::uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpDPFieldWindow)
return mpDPFieldWindow->GetFieldText(getAccessibleIndexInParent());
diff --git a/sc/source/ui/Accessibility/AccessibleDocument.cxx b/sc/source/ui/Accessibility/AccessibleDocument.cxx
index 18ba35d..debe93c 100644
--- a/sc/source/ui/Accessibility/AccessibleDocument.cxx
+++ b/sc/source/ui/Accessibility/AccessibleDocument.cxx
@@ -36,7 +36,6 @@
#include "AccessibilityHints.hxx"
#include "document.hxx"
#include "drwlayer.hxx"
-#include "unoguard.hxx"
#include "shapeuno.hxx"
#include "DrawModelBroadcaster.hxx"
#include "drawview.hxx"
@@ -66,6 +65,7 @@
#include <svx/unoshape.hxx>
#include <unotools/accessiblerelationsethelper.hxx>
#include <toolkit/helper/convert.hxx>
+#include <vcl/svapp.hxx>
#include <list>
#include <algorithm>
@@ -1277,7 +1277,7 @@ ScAccessibleDocument::~ScAccessibleDocument(void)
void SAL_CALL ScAccessibleDocument::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
FreeAccessibleSpreadsheet();
if (mpViewShell)
{
@@ -1513,7 +1513,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleDocument::getAccessibleAtPoin
uno::Reference<XAccessible> xAccessible = NULL;
if (containsPoint(rPoint))
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpChildrenShapes)
xAccessible = mpChildrenShapes->GetAt(rPoint);
@@ -1540,7 +1540,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleDocument::getAccessibleAtPoin
void SAL_CALL ScAccessibleDocument::grabFocus( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (getAccessibleParent().is())
{
@@ -1566,7 +1566,7 @@ sal_Int32 SAL_CALL
ScAccessibleDocument::getAccessibleChildCount(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nCount(1);
if (mpChildrenShapes)
@@ -1584,7 +1584,7 @@ uno::Reference<XAccessible> SAL_CALL
throw (uno::RuntimeException,
lang::IndexOutOfBoundsException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
uno::Reference<XAccessible> xAccessible;
if (nIndex >= 0)
@@ -1615,7 +1615,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
ScAccessibleDocument::getAccessibleStateSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
uno::Reference<XAccessibleStateSet> xParentStates;
if (getAccessibleParent().is())
{
@@ -1645,7 +1645,7 @@ void SAL_CALL
ScAccessibleDocument::selectAccessibleChild( sal_Int32 nChildIndex )
throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpChildrenShapes)
@@ -1679,7 +1679,7 @@ sal_Bool SAL_CALL
ScAccessibleDocument::isAccessibleChildSelected( sal_Int32 nChildIndex )
throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Bool bResult(sal_False);
@@ -1712,7 +1712,7 @@ void SAL_CALL
ScAccessibleDocument::clearAccessibleSelection( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpChildrenShapes)
@@ -1723,7 +1723,7 @@ void SAL_CALL
ScAccessibleDocument::selectAllAccessibleChildren( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpChildrenShapes)
@@ -1740,7 +1740,7 @@ sal_Int32 SAL_CALL
ScAccessibleDocument::getSelectedAccessibleChildCount( )
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
sal_Int32 nCount(0);
@@ -1760,7 +1760,7 @@ uno::Reference<XAccessible > SAL_CALL
ScAccessibleDocument::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
uno::Reference<XAccessible> xAccessible;
if (mpChildrenShapes)
@@ -1788,7 +1788,7 @@ void SAL_CALL
ScAccessibleDocument::deselectAccessibleChild( sal_Int32 nChildIndex )
throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (mpChildrenShapes)
@@ -1850,7 +1850,7 @@ uno::Sequence<sal_Int8> SAL_CALL
ScAccessibleDocument::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
@@ -1865,7 +1865,7 @@ uno::Sequence<sal_Int8> SAL_CALL
sal_Bool ScAccessibleDocument::IsValid (void) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return (!ScAccessibleContextBase::IsDefunc() && !rBHelper.bInDispose);
}
@@ -1888,14 +1888,14 @@ Rectangle ScAccessibleDocument::GetVisibleArea_Impl() const
Rectangle ScAccessibleDocument::GetVisibleArea() const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
return maVisArea;
}
Point ScAccessibleDocument::LogicToPixel (const Point& rPoint) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
Point aPoint;
ScGridWindow* pWin = static_cast<ScGridWindow*>(mpViewShell->GetWindowByPos(meSplitPos));
@@ -1909,7 +1909,7 @@ Point ScAccessibleDocument::LogicToPixel (const Point& rPoint) const
Size ScAccessibleDocument::LogicToPixel (const Size& rSize) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
Size aSize;
ScGridWindow* pWin = static_cast<ScGridWindow*>(mpViewShell->GetWindowByPos(meSplitPos));
@@ -1920,7 +1920,7 @@ Size ScAccessibleDocument::LogicToPixel (const Size& rSize) const
Point ScAccessibleDocument::PixelToLogic (const Point& rPoint) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
Point aPoint;
ScGridWindow* pWin = static_cast<ScGridWindow*>(mpViewShell->GetWindowByPos(meSplitPos));
@@ -1934,7 +1934,7 @@ Point ScAccessibleDocument::PixelToLogic (const Point& rPoint) const
Size ScAccessibleDocument::PixelToLogic (const Size& rSize) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
Size aSize;
ScGridWindow* pWin = static_cast<ScGridWindow*>(mpViewShell->GetWindowByPos(meSplitPos));
@@ -1965,7 +1965,7 @@ utl::AccessibleRelationSetHelper* ScAccessibleDocument::GetRelationSet(const ScA
ScAccessibleDocument::createAccessibleName(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
rtl::OUString sName = String(ScResId(STR_ACC_DOC_NAME));
sal_Int32 nNumber(sal_Int32(meSplitPos) + 1);
diff --git a/sc/source/ui/Accessibility/AccessibleDocumentPagePreview.cxx b/sc/source/ui/Accessibility/AccessibleDocumentPagePreview.cxx
index 02435a2..cc2fc0f 100644
--- a/sc/source/ui/Accessibility/AccessibleDocumentPagePreview.cxx
+++ b/sc/source/ui/Accessibility/AccessibleDocumentPagePreview.cxx
@@ -37,7 +37,6 @@
#include "document.hxx"
#include "prevwsh.hxx"
#include "prevloc.hxx"
-#include "unoguard.hxx"
#include "drwlayer.hxx"
#include "editsrc.hxx"
#include "scresid.hxx"
@@ -63,6 +62,7 @@
#include <toolkit/helper/convert.hxx>
#include <svx/unoshape.hxx>
#include <unotools/accessiblerelationsethelper.hxx>
+#include <vcl/svapp.hxx>
#include <vector>
#include <list>
@@ -568,13 +568,13 @@ ScIAccessibleViewForwarder::~ScIAccessibleViewForwarder()
sal_Bool ScIAccessibleViewForwarder::IsValid (void) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
return mbValid;
}
Rectangle ScIAccessibleViewForwarder::GetVisibleArea() const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
Rectangle aVisRect;
Window* pWin = mpViewShell->GetWindow();
if (pWin)
@@ -590,7 +590,7 @@ Rectangle ScIAccessibleViewForwarder::GetVisibleArea() const
Point ScIAccessibleViewForwarder::LogicToPixel (const Point& rPoint) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
Point aPoint;
Window* pWin = mpViewShell->GetWindow();
if (pWin && mpAccDoc)
@@ -604,7 +604,7 @@ Point ScIAccessibleViewForwarder::LogicToPixel (const Point& rPoint) const
Size ScIAccessibleViewForwarder::LogicToPixel (const Size& rSize) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
Size aSize;
Window* pWin = mpViewShell->GetWindow();
if (pWin)
@@ -614,7 +614,7 @@ Size ScIAccessibleViewForwarder::LogicToPixel (const Size& rSize) const
Point ScIAccessibleViewForwarder::PixelToLogic (const Point& rPoint) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
Point aPoint;
Window* pWin = mpViewShell->GetWindow();
if (pWin && mpAccDoc)
@@ -627,7 +627,7 @@ Point ScIAccessibleViewForwarder::PixelToLogic (const Point& rPoint) const
Size ScIAccessibleViewForwarder::PixelToLogic (const Size& rSize) const
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
Size aSize;
Window* pWin = mpViewShell->GetWindow();
if (pWin)
@@ -1448,7 +1448,7 @@ ScAccessibleDocumentPagePreview::~ScAccessibleDocumentPagePreview(void)
void SAL_CALL ScAccessibleDocumentPagePreview::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (mpTable)
{
mpTable->release();
@@ -1581,7 +1581,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleDocumentPagePreview::getAcces
uno::Reference<XAccessible> xAccessible;
if (containsPoint(rPoint))
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if ( mpViewShell )
@@ -1655,7 +1655,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleDocumentPagePreview::getAcces
void SAL_CALL ScAccessibleDocumentPagePreview::grabFocus() throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (getAccessibleParent().is())
{
@@ -1672,7 +1672,7 @@ void SAL_CALL ScAccessibleDocumentPagePreview::grabFocus() throw (uno::RuntimeEx
sal_Int32 SAL_CALL ScAccessibleDocumentPagePreview::getAccessibleChildCount(void) throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
long nRet = 0;
@@ -1688,7 +1688,7 @@ sal_Int32 SAL_CALL ScAccessibleDocumentPagePreview::getAccessibleChildCount(void
uno::Reference<XAccessible> SAL_CALL ScAccessibleDocumentPagePreview::getAccessibleChild(sal_Int32 nIndex)
throw (uno::RuntimeException, lang::IndexOutOfBoundsException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
uno::Reference<XAccessible> xAccessible;
@@ -1754,7 +1754,7 @@ uno::Reference<XAccessible> SAL_CALL ScAccessibleDocumentPagePreview::getAccessi
uno::Reference<XAccessibleStateSet> SAL_CALL ScAccessibleDocumentPagePreview::getAccessibleStateSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
uno::Reference<XAccessibleStateSet> xParentStates;
if (getAccessibleParent().is())
{
@@ -1804,7 +1804,7 @@ uno::Sequence<sal_Int8> SAL_CALL
ScAccessibleDocumentPagePreview::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
diff --git a/sc/source/ui/Accessibility/AccessibleEditObject.cxx b/sc/source/ui/Accessibility/AccessibleEditObject.cxx
index ccfc6c3..b0cc9e9 100644
--- a/sc/source/ui/Accessibility/AccessibleEditObject.cxx
+++ b/sc/source/ui/Accessibility/AccessibleEditObject.cxx
@@ -31,7 +31,6 @@
#include "AccessibleEditObject.hxx"
#include "scitems.hxx"
#include <editeng/eeitem.hxx>
-#include "unoguard.hxx"
#include "AccessibleText.hxx"
#include "editsrc.hxx"
#include "scmod.hxx"
@@ -46,6 +45,7 @@
#include <editeng/editview.hxx>
#include <editeng/editeng.hxx>
#include <svx/svdmodel.hxx>
+#include <vcl/svapp.hxx>
using namespace ::com::sun::star;
using namespace ::com::sun::star::accessibility;
@@ -82,7 +82,7 @@ ScAccessibleEditObject::~ScAccessibleEditObject()
void SAL_CALL ScAccessibleEditObject::disposing()
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
if (mpTextHelper)
DELETEZ(mpTextHelper);
@@ -114,7 +114,7 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleEditObject::getAccessibleAtPo
uno::Reference<XAccessible> xRet;
if (containsPoint(rPoint))
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if(!mpTextHelper)
@@ -193,7 +193,7 @@ sal_Int32 SAL_CALL
ScAccessibleEditObject::getAccessibleChildCount(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (!mpTextHelper)
CreateTextHelper();
@@ -205,7 +205,7 @@ uno::Reference< XAccessible > SAL_CALL
throw (uno::RuntimeException,
lang::IndexOutOfBoundsException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
if (!mpTextHelper)
CreateTextHelper();
@@ -216,7 +216,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
ScAccessibleEditObject::getAccessibleStateSet(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
uno::Reference<XAccessibleStateSet> xParentStates;
if (getAccessibleParent().is())
{
@@ -296,7 +296,7 @@ uno::Sequence<sal_Int8> SAL_CALL
ScAccessibleEditObject::getImplementationId(void)
throw (uno::RuntimeException)
{
- ScUnoGuard aGuard;
+ SolarMutexGuard aGuard;
IsObjectValid();
static uno::Sequence<sal_Int8> aId;
if (aId.getLength() == 0)
diff --git a/sc/source/filter/xml/xmlimprt.cxx b/sc/source/filter/xml/xmlimprt.cxx
index 9a2e9ae..612fd8c 100644
--- a/sc/source/filter/xml/xmlimprt.cxx
+++ b/sc/source/filter/xml/xmlimprt.cxx
@@ -60,7 +60,6 @@
#include "nameuno.hxx"
#include "xmlbodyi.hxx"
#include "xmlstyli.hxx"
-#include "unoguard.hxx"
#include "ViewSettingsSequenceDefines.hxx"
#include "patattr.hxx"
@@ -1742,7 +1741,7 @@ ScXMLImport::ScXMLImport(
pMyLabelRanges(NULL),
pValidations(NULL),
pDetectiveOpArray(NULL),
- pScUnoGuard(NULL),
+ pSolarMutexGuard(NULL),
pNumberFormatAttributesExportHelper(NULL),
pStyleNumberFormats(NULL),
sPrevStyleName(),
@@ -1873,8 +1872,8 @@ ScXMLImport::~ScXMLImport() throw()
if (pStylesImportHelper)
delete pStylesImportHelper;
- if (pScUnoGuard)
- delete pScUnoGuard;
+ if (pSolarMutexGuard)
+ delete pSolarMutexGuard;
if (pMyNamedExpressions)
delete pMyNamedExpressions;
@@ -2914,7 +2913,7 @@ void ScXMLImport::DisposingModel()
void ScXMLImport::LockSolarMutex()
{
// #i62677# When called from DocShell/Wrapper, the SolarMutex is already locked,
// so there's no need to allocate (and later delete) the ScUnoGuard.
if (bFromWrapper)
{
DBG_TESTSOLARMUTEX();
@@ -2923,8 +2922,8 @@ void ScXMLImport::LockSolarMutex()
if (nSolarMutexLocked == 0)
{
- DBG_ASSERT(!pScUnoGuard, "Solar Mutex is locked");
- pScUnoGuard = new ScUnoGuard();
+ DBG_ASSERT(!pSolarMutexGuard, "Solar Mutex is locked");
+ pSolarMutexGuard = new SolarMutexGuard();
}
++nSolarMutexLocked;
}
@@ -2937,9 +2936,9 @@ void ScXMLImport::UnlockSolarMutex()
nSolarMutexLocked--;
if (nSolarMutexLocked == 0)
{
- DBG_ASSERT(pScUnoGuard, "Solar Mutex is always unlocked");
- delete pScUnoGuard;
- pScUnoGuard = NULL;
+ DBG_ASSERT(pSolarMutexGuard, "Solar Mutex is always unlocked");
+ delete pSolarMutexGuard;
+ pSolarMutexGuard = NULL;
}
}
}
@@ -2914,7 +2913,7 @@ void ScXMLImport::DisposingModel()
{
// #i62677# When called from DocShell/Wrapper, the SolarMutex is already locked,
- // so there's no need to allocate (and later delete) the ScUnoGuard.
+ // so there's no need to allocate (and later delete) the SolarMutexGuard.
if (bFromWrapper)
{
diff --git a/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx b/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx
index d3a999a..2bbb515 100644
--- a/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list